@@ -5,7 +5,7 @@ function(bigQR, X, y, w=NULL,
     stop("Wrong number of columns")
   if (length(y)!=NROW(X))
     stop("Wrong number of rows")
-  if (is.null(w)) w<-rep(1.0, length(y))
+  if (length(w)==0) w<-rep(1.0, length(y))
   if (length(y)!=length(w))
     stop("`weights' has wrong length")
   storage.mode(X)<-"double"
